Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(234)

Unified Diff: chrome/browser/content_settings/tab_specific_content_settings.h

Issue 1158813002: Use RenderFrameHost for ::RequestPermission() and ::CancelPermission(). (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/content_settings/tab_specific_content_settings.h
diff --git a/chrome/browser/content_settings/tab_specific_content_settings.h b/chrome/browser/content_settings/tab_specific_content_settings.h
index 0bc6ec6c59e9008c7da71fe698b0f3ca34461b58..bc80bf9788784e586183e705f9089fd1d5d6a36e 100644
--- a/chrome/browser/content_settings/tab_specific_content_settings.h
+++ b/chrome/browser/content_settings/tab_specific_content_settings.h
@@ -83,9 +83,9 @@ class TabSpecificContentSettings
~TabSpecificContentSettings() override;
- // Returns the object given a render view's id.
- static TabSpecificContentSettings* Get(int render_process_id,
- int render_view_id);
+ // Returns the object given a RenderFrameHost.
+ static TabSpecificContentSettings* Get(
+ content::RenderFrameHost* render_frame_host);
// Static methods called on the UI threads.
// Called when cookies for the given URL were read either from within the

Powered by Google App Engine
This is Rietveld 408576698